
## CATO-CLI - query.admin:
[Click here](https://api.catonetworks.com/documentation/#query-admin) for documentation on this operation.

### Usage for query.admin:

`catocli query admin -h`

`catocli query admin <accountID> <json>`

`catocli query admin 12345 "$(cat < admin.json)"`

`catocli query admin 12345 '{"adminID": "ID"}'`

#### Operation Arguments for query.admin ####
`accountId` [ID] - (required) N/A 
`adminID` [ID] - (required) N/A 
